import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 外委保养工单服务对象基类
 *
 * @export
 * @class EMWO_OSCServiceBase
 * @extends {EntityServie}
 */
export default class EMWO_OSCServiceBase extends EntityService {

    /**
     * Creates an instance of  EMWO_OSCServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EMWO_OSCServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EMWO_OSCServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='emwo_osc';
        this.APPDEKEY = 'emwo_oscid';
        this.APPDENAME = 'emwo_oscs';
        this.APPDETEXT = 'emwo_oscname';
        this.APPNAME = 'eamweb';
        this.SYSTEMNAME = 'eam_practice04';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && context.emwo_osc){
            return Http.getInstance().get(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/select`,isloading);
        }
        if(context.emeqtype && context.emequip && context.emwo_osc){
            return Http.getInstance().get(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/select`,isloading);
        }
        if(context.emequip && context.emwo_osc){
            return Http.getInstance().get(`/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/select`,isloading);
        }
            return Http.getInstance().get(`/emwo_oscs/${context.emwo_osc}/select`,isloading);
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && true){
            return Http.getInstance().get(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/getdraft`,isloading);
        }
        if(context.emeqtype && context.emequip && true){
            return Http.getInstance().get(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/getdraft`,isloading);
        }
        if(context.emequip && true){
            return Http.getInstance().get(`/emequips/${context.emequip}/emwo_oscs/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/emwo_oscs/getdraft`,isloading);
        res.data.emwo_osc = data.emwo_osc;
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && context.emwo_osc){
            return Http.getInstance().put(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,data,isloading);
        }
        if(context.emeqtype && context.emequip && context.emwo_osc){
            return Http.getInstance().put(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,data,isloading);
        }
        if(context.emequip && context.emwo_osc){
            return Http.getInstance().put(`/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/emwo_oscs/${context.emwo_osc}`,data,isloading);
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && context.emwo_osc){
            return Http.getInstance().post(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/checkkey`,data,isloading);
        }
        if(context.emeqtype && context.emequip && context.emwo_osc){
            return Http.getInstance().post(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/checkkey`,data,isloading);
        }
        if(context.emequip && context.emwo_osc){
            return Http.getInstance().post(`/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/emwo_oscs/${context.emwo_osc}/checkkey`,data,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && context.emwo_osc){
            return Http.getInstance().get(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,isloading);
        }
        if(context.emeqtype && context.emequip && context.emwo_osc){
            return Http.getInstance().get(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,isloading);
        }
        if(context.emequip && context.emwo_osc){
            return Http.getInstance().get(`/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/emwo_oscs/${context.emwo_osc}`,isloading);
            return res;

    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs`,data,isloading);
        }
        if(context.emeqtype && context.emequip && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs`,data,isloading);
        }
        if(context.emequip && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emequips/${context.emequip}/emwo_oscs`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/emwo_oscs`,data,isloading);
        return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && context.emwo_osc){
            return Http.getInstance().post(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/save`,data,isloading);
        }
        if(context.emeqtype && context.emequip && context.emwo_osc){
            return Http.getInstance().post(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/save`,data,isloading);
        }
        if(context.emequip && context.emwo_osc){
            return Http.getInstance().post(`/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}/save`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/emwo_oscs/${context.emwo_osc}/save`,data,isloading);
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && context.emwo_osc){
            return Http.getInstance().delete(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,isloading);
        }
        if(context.emeqtype && context.emequip && context.emwo_osc){
            return Http.getInstance().delete(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,isloading);
        }
        if(context.emequip && context.emwo_osc){
            return Http.getInstance().delete(`/emequips/${context.emequip}/emwo_oscs/${context.emwo_osc}`,isloading);
        }
            return Http.getInstance().delete(`/emwo_oscs/${context.emwo_osc}`,isloading);

    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMWO_OSCServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.pfteam && context.emequip && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/pfteams/${context.pfteam}/emequips/${context.emequip}/emwo_oscs/fetchdefault`,tempData,isloading);
        }
        if(context.emeqtype && context.emequip && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emeqtypes/${context.emeqtype}/emequips/${context.emequip}/emwo_oscs/fetchdefault`,tempData,isloading);
        }
        if(context.emequip && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emequips/${context.emequip}/emwo_oscs/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/emwo_oscs/fetchdefault`,tempData,isloading);
    }
}